#version 3.7;

#include "colors.inc"
#include "metals.inc"
#include "glass.inc"
#include "textures.inc"
#include "math.inc"

// In this file, units are kilometers

//--------------------------------------------------------------------------
global_settings {
    assumed_gamma 1.0
    ambient_light 0
    max_trace_level 20
}  
default { finish { ambient 0 } }
//--------------------------------------------------------------------------


// Sun
light_source { <2e3, .5e3, 7e3>, 1 parallel }

#declare rfeature = 125 / 100e3 / 16; // 125 meter main feature size

#declare bmissile = normal {
  bump_map {
    png "robo-missiles.png"
    bump_size 3e-3 *5
  }
  no_bump_scale
};  
#declare bbfr = normal {
  bump_map {
    png "robo-bfr.png"
    bump_size 8e-3 *5
  }
  no_bump_scale
};  

#declare missiles = normal { 
  bmissile
  scale <rfeature, rfeature * 2, rfeature>
  no_bump_scale
};

#declare bfrs = normal { 
  bbfr
  scale <rfeature, rfeature * 2, rfeature>
  no_bump_scale
};

#declare moon_finish = finish {
  brilliance 0.1
  //reflection 0.3
  diffuse 0.25
  metallic
  //reflection { 0.3 metallic }
};

#declare moon_texture = texture {
  pigment { color srgb <0.55 0.60 0.65> }
  finish { moon_finish }
};
  
#declare pmain = texture {
  moon_texture
  normal { 
    bmissile//missiles 
  }
};

#declare pbfr = texture {
  moon_texture
  normal { 
    bbfr//bfrs
  }
};

#declare tmoon = texture 
{ 
  cells
  texture_map {
    [ 0.0 pbfr ]
    [ 0.4 pbfr ]
    [ 0.4 pmain ]
    [ 1.0 pmain ]
  }
  scale <rfeature, rfeature * 2, 1>
  no_bump_scale
  warp {spherical}
}

#declare moonobj = sphere { <0, 0, 0>, 50  // 100 km diameter
  rotate <0, 0, 180> translate <-300, 0, 0> }

// Robo-moon
object { moonobj texture { tmoon } }

// declares position and view direction

#declare cam_sky      = z;
#declare cam_angle    = 55; 

#declare taj_location = <-250.2, 0.01, -0.04>;
#declare taj_location = <-249.2, 0.1, 0.03>;
//#declare taj_location = <-248, 0.1, 0.03>;
//#declare taj_location = <-245, 0.5, 0.03>;
//#declare taj_location = <-235, 0.5, 0.03>;

#declare cam_location = <0, -50000, 130000>;
#declare cam_look_at  = taj_location;

#declare cam_location = <-249.2, 0.1, 0.03>;

#declare cam_offset = <0.1, 0.04, 0.02>*3;
//#declare cam_offset = <1, 0.04, 0.02>*2;

#declare cam_location = taj_location + cam_offset;

//#declare cam_location = <-240, 0.1, 0.03>;
//#declare cam_location = <-200, 0.1, 0.03>;

camera { up z right x * (-image_width / image_height)
  location  cam_location
  look_at   cam_look_at
  sky       cam_sky
  angle     cam_angle 
}
